# VisuaLife : scientific visualization in a browser!

VisuaLive is a Brython library for creating live and interactive visualization of scientific data

Documentation fot this project is hosted on [Read the Docs](https://visualife.readthedocs.io/en/latest/index.html),
which unfortunately sucks and cannot generate it correctly. Complete (but a bit old) documentation may be
[found here](http://bioshell.pl/~bioshell/documentation/visualife/)

In order to run th demos, use any HTTP server, e.g. the one which comes with your Python installation:

python3 -m http.server